@@ -19,7 +19,6 @@ from datetime import datetime
 from typing import Optional, Dict, List
 from itertools import chain
 
-
 import rqalpha
 from rqalpha.core.events import EventBus
 from rqalpha.const import INSTRUMENT_TYPE
@@ -53,7 +52,7 @@ class Environment(object):
         self.trading_dt = None  # type: Optional[datetime]
         self.mod_dict = None
         self.user_strategy = None
-        self._frontend_validators = {}  # type: Dict[INSTRUMENT_TYPE, List]
+        self._frontend_validators = {}  # type: Dict[str, List]
         self._default_frontend_validators = []
         self._transaction_cost_decider_dict = {}
 
@@ -110,16 +109,18 @@ class Environment(object):
         else:
             self._default_frontend_validators.append(validator)
 
-    def can_submit_order(self, order):
-        instrument_type = self.data_proxy.instruments(order.order_book_id).type
+    def _get_frontend_validators(self, instrument_type):
+        return chain(self._frontend_validators.get(instrument_type, []), self._default_frontend_validators)
+
+    def submit_order(self, order):
+        instrument_type = self.data_proxy.instrument(order.order_book_id).type
         account = self.portfolio.get_account(order.order_book_id)
-        for v in chain(self._frontend_validators.get(instrument_type, []), self._default_frontend_validators):
-            if not v.can_submit_order(order, account):
-                return False
-        return True
+        if all(v.can_submit_order(order, account) for v in self._get_frontend_validators(instrument_type)):
+            self.broker.submit_order(order)
+            return order
 
     def can_cancel_order(self, order):
-        instrument_type = self.data_proxy.instruments(order.order_book_id).type
+        instrument_type = self.data_proxy.instrument(order.order_book_id).type
         account = self.portfolio.get_account(order.order_book_id)
         for v in chain(self._frontend_validators.get(instrument_type, []), self._default_frontend_validators):
             if not v.can_cancel_order(order, account):
@@ -139,7 +140,7 @@ class Environment(object):
         return self.data_proxy.get_last_price(order_book_id)
 
     def get_instrument(self, order_book_id):
-        return self.data_proxy.instruments(order_book_id)
+        return self.data_proxy.instrument(order_book_id)
 
     def get_account_type(self, order_book_id):
         return self.portfolio.get_account_type(order_book_id)
@@ -155,7 +156,7 @@ class Environment(object):
         self._transaction_cost_decider_dict[instrument_type] = decider
 
     def _get_transaction_cost_decider(self, order_book_id):
-        instrument_type = self.data_proxy.instruments(order_book_id).type
+        instrument_type = self.data_proxy.instrument(order_book_id).type
         try:
             return self._transaction_cost_decider_dict[instrument_type]
         except KeyError:
@@ -176,3 +177,12 @@ class Environment(object):
         # type: (datetime, datetime) -> None
         self.calendar_dt = calendar_dt
         self.trading_dt = trading_dt
+
+    def can_submit_order(self, order):
+        # forward compatible
+        instrument_type = self.data_proxy.instrument(order.order_book_id).type
+        account = self.portfolio.get_account(order.order_book_id)
+        for v in self._get_frontend_validators(instrument_type):
+            if not v.can_submit_order(order, account):
+                return False
+        return True
\ No newline at end of file
