@@ -1,4 +1,4 @@
-from rqalpha.api import *
+from rqalpha.apis import *
 
 
 # 在这个方法中编写任何的初始化逻辑。context对象将会在你的算法策略的任何方法之间做传递。
