@@ -35,26 +35,28 @@ rcParams['axes.unicode_minus'] = False
 font = findfont(FontProperties(family=['sans-serif']))
 if "/matplotlib/" in font:
     system_log.warn("PLOT: Missing Chinese fonts. Fallback to English.")
-    LABEL_FONT_SIZE = 8
+    LABEL_FONT_SIZE = 9
     _ = lambda txt: txt
+    SUPPORT_CHINESE = False
 else:
-    LABEL_FONT_SIZE = 10
+    LABEL_FONT_SIZE = 11
+    SUPPORT_CHINESE = True
 
 RED = "#aa4643"
 BLUE = "#4572a7"
 YELLOW = "#F3A423"
 BLACK = "#000000"
 
-IMG_WIDTH = 13
+IMG_WIDTH = 15
 # 两部分的相对高度
-INDICATOR_AREA_HEIGHT = 2
-PLOT_AREA_HEIGHT = 4
+INDICATOR_AREA_HEIGHT = 3
+PLOT_AREA_HEIGHT = 5
 USER_PLOT_AREA_HEIGHT = 2
 
 # 指标的宽高
-INDICATOR_WIDTH = 0.15
+INDICATOR_WIDTH = 0.18
 INDICATOR_VALUE_HEIGHT = 0.15
-INDICATOR_LABEL_HEIGHT = 0.2
+INDICATOR_LABEL_HEIGHT = 0.1
 
 LINE_STRATEGY = LineInfo(_("Strategy"), RED, 1, 2)
 LINE_BENCHMARK = LineInfo(_("Benchmark"), BLUE, 1, 2)
@@ -74,14 +76,19 @@ INDICATORS = [[
     IndicatorInfo("beta", _("Beta"), BLACK, "{0:.4}", 11),
     IndicatorInfo("sharpe", _("Sharpe"), BLACK, "{0:.4}", 11),
     IndicatorInfo("sortino", _("Sortino"), BLACK, "{0:.4}", 11),
-    IndicatorInfo("information_ratio", _("InformationRatio"), BLACK, "{0:.4}", 11),
 ], [
     IndicatorInfo("benchmark_total_returns", _("BenchmarkReturns"), BLUE, "{0:.3%}", 11),
     IndicatorInfo("benchmark_annualized_returns", _("BenchmarkAnnual"), BLUE, "{0:.3%}", 11),
     IndicatorInfo("volatility", _("Volatility"), BLACK, "{0:.4}", 11),
-    IndicatorInfo("max_drawdown", _("MaxDrawDown"), BLACK, "{0:.4}", 11),
     IndicatorInfo("tracking_error", _("TrackingError"), BLACK, "{0:.4}", 11),
     IndicatorInfo("downside_risk", _("DownsideRisk"), BLACK, "{0:.4}", 11),
+    IndicatorInfo("information_ratio", _("InformationRatio"), BLACK, "{0:.4}", 11),
+], [
+    IndicatorInfo("excess_cum_returns", _("ExcessCumReturns"), BLACK, "{0:.3%}", 11),
+    IndicatorInfo("win_rate", _("WinRate"), BLACK, "{0:.4}", 11),
+    IndicatorInfo("weekly_win_rate", _("WeeklyWinRate"), BLACK, "{0:.4}", 11),
+    IndicatorInfo("profit_loss_rate", _("ProfitLossRate"), BLACK, "{0:.4}", 11),
+    IndicatorInfo("max_drawdown", _("MaxDrawDown"), BLACK, "{0:.4}", 11),
     IndicatorInfo("max_dd_ddd", _("MaxDD/MaxDDD"), BLACK, "{}", 6),
 ]]
 
@@ -89,19 +96,16 @@ WEEKLY_INDICATORS = [
     IndicatorInfo("weekly_alpha", _("WeeklyAlpha"), BLACK, "{0:.4}", 11),
     IndicatorInfo("weekly_beta", _("WeeklyBeta"), BLACK, "{0:.4}", 11),
     IndicatorInfo("weekly_sharpe", _("WeeklySharpe"), BLACK, "{0:.4}", 11),
-    IndicatorInfo("weekly_sortino", _("WeeklySortino"), BLACK, "{0:.4}", 11),
     IndicatorInfo("weekly_information_ratio", _("WeeklyInfoRatio"), BLACK, "{0:.4}", 11),
     IndicatorInfo("weekly_tracking_error", _("WeeklyTrackingError"), BLACK, "{0:.4}", 11),
     IndicatorInfo("weekly_max_drawdown", _("WeeklyMaxDrawdown"), BLACK, "{0:.4}", 11),
 ]
 
 EXCESS_INDICATORS = [
-    IndicatorInfo("excess_cum_returns", _("ExcessCumReturns"), RED, "{0:.3%}", 11),
-    IndicatorInfo("excess_returns", _("ExcessReturns"), RED, "{0:.3%}", 11),
+    IndicatorInfo("excess_returns", _("ExcessReturns"), BLACK, "{0:.3%}", 11),
     IndicatorInfo("excess_annual_returns", _("ExcessAnnual"), BLACK, "{0:.3%}", 11),
     IndicatorInfo("excess_sharpe", _("ExcessSharpe"), BLACK, "{0:.4}", 11),
     IndicatorInfo("excess_volatility", _("ExcessVolatility"), BLACK, "{0:.4}", 11),
-    # IndicatorInfo("excess_annual_volatility", _("ExcessAnnualVolatility"), BLACK, "{0:.4}", 11),
     IndicatorInfo("excess_max_drawdown", _("ExcessMaxDD"), BLACK, "{0:.4}", 11),
     IndicatorInfo("excess_max_dd_ddd", _("ExcessMaxDD/ExcessMaxDDD"), BLACK, "{}", 6),
 ]
