@@ -10,13 +10,14 @@ def handle_bar(context, bar_dict):
 
 __config__ = {
     "base": {
-        "securities": "future",
         "start_date": "2015-01-09",
         "end_date": "2015-03-09",
         "frequency": "1d",
         "matching_type": "current_bar",
-        "future_starting_cash": 1000000,
         "benchmark": None,
+        "accounts": {
+            "future": 1000000
+        }
     },
     "extra": {
         "log_level": "error",
